@@ -137,11 +137,11 @@ class AsYouTypeFormatter(object):
     def _get_available_formats(self, leading_digits):
         if (self._is_complete_number and
             len(self._current_metadata.intl_number_format) > 0):
-            number_formats = self._current_metadata.intl_number_format
+            format_list = self._current_metadata.intl_number_format
         else:
-            number_formats = self._current_metadata.number_format
+            format_list = self._current_metadata.number_format
         national_prefix_is_used_by_country = (self._current_metadata.national_prefix is not None)
-        for this_format in number_formats:
+        for this_format in format_list:
             if (not national_prefix_is_used_by_country or self._is_complete_number or
                 this_format.national_prefix_optional_when_formatting or
                 _formatting_rule_has_first_group_only(this_format.national_prefix_formatting_rule)):
@@ -537,7 +537,6 @@ class AsYouTypeFormatter(object):
         if len(self._national_number) == 0:
             return False
 
-        number_without_ccc = U_EMPTY_STRING
         country_code, number_without_ccc = _extract_country_code(self._national_number)
         if country_code == 0:
             return False
